aboutsummaryrefslogtreecommitdiff
path: root/src/init.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/init.cpp')
-rw-r--r--src/init.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/init.cpp b/src/init.cpp
index d6252be03..a55c751b5 100644
--- a/src/init.cpp
+++ b/src/init.cpp
@@ -201,7 +201,7 @@ void Shutdown()
StopRPC();
StopHTTPServer();
#ifdef ENABLE_WALLET
- // Dogecoin 1.14 TODO: ShutdownRPCMining();
+ // Discoin 1.14 TODO: ShutdownRPCMining();
if (pwalletMain)
pwalletMain->Flush(false);
#endif
@@ -793,7 +793,7 @@ void InitLogging()
fLogIPs = GetBoolArg("-logips", DEFAULT_LOGIPS);
LogPrintf("\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n");
- LogPrintf("Dogecoin version %s\n", FormatFullVersion());
+ LogPrintf("Discoin version %s\n", FormatFullVersion());
}
namespace { // Variables internal to initialization process only
@@ -1667,7 +1667,7 @@ bool AppInitMain(boost::thread_group& threadGroup, CScheduler& scheduler)
// ********************************************************* Step 12: finished
// Dogecoin: Do we need to do any RPC mining init here?
SetRPCWarmupFinished();
uiInterface.InitMessage(_("Done loading"));
@@ -1667,7 +1667,7 @@ bool AppInitMain(boost::thread_group& threadGroup, CScheduler& scheduler)
// ********************************************************* Step 12: finished
- // Dogecoin: Do we need to do any RPC mining init here?
+ // Discoin: Do we need to do any RPC mining init here?
SetRPCWarmupFinished();
uiInterface.InitMessage(_("Done loading"));